#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : __init__.py
# @Time         : 2020-03-04 14:46
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

class Config(object):
    zk_cfg = None

# TODO
# from pydantic import BaseModel
# class A(BaseModel):
#     a: str = None
#
#
# A().dict()
